"""RAG chain: retrieval-augmented generation with citations."""

from pinrag.rag.chain import RAGResult, run_rag
from pinrag.rag.formatting import format_docs, format_sources
from pinrag.rag.prompts import RAG_PROMPT

__all__ = [
    "RAGResult",
    "RAG_PROMPT",
    "format_docs",
    "format_sources",
    "run_rag",
]
